@@ -22,24 +22,31 @@ from pulp_2to3_migration.app.models import (
 _logger = logging.getLogger(__name__)
 
 
-def migrate_content(plan):
+def migrate_content(plan, skip_corrupted=False):
     """
     A coroutine to initiate content migration for each plugin.
 
     Args:
          plan (MigrationPlan): Migration Plan to use
+         skip_corrupted (bool): If True, corrupted content is skipped during migration,
+                                no task failure.
+
     """
     progress_data = dict(message='Migrating content to Pulp 3', code='migrating.content', total=0)
     with ProgressReport(**progress_data) as pb:
         # schedule content migration into Pulp 3 using pre-migrated Pulp 2 content
         for plugin in plan.get_plugin_plans():
-            plugin.migrator.migrate_content_to_pulp3()
-
             # only used for progress bar counters
             content_types = plugin.migrator.content_models.keys()
-            pulp2content_qs = Pulp2Content.objects.filter(pulp2_content_type_id__in=content_types,
-                                                          pulp3_content=None)
-            pb.total += pulp2content_qs.count()
+            num_to_migrate = Pulp2Content.objects.filter(
+                pulp2_content_type_id__in=content_types,
+                pulp3_content=None
+            ).count()
+
+            # migrate
+            plugin.migrator.migrate_content_to_pulp3(skip_corrupted=skip_corrupted)
+
+            pb.total += num_to_migrate
             pb.done = pb.total
             pb.save()
 
@@ -269,6 +276,9 @@ def complex_repo_migration(plugin, pulp3_repo_setup, repo_name):
                     dist_migrator, progress_dist, dist,
                     migrated_repo.pulp3_repository_version
                 )
+                # add distirbutors specified in the complex plan
+                # these can be native and not native distributors
+                migrated_repo.pulp2_dists.add(dist)
 
 
 def create_repoversions_publications_distributions(plan, parallel=True):
