@@ -110,7 +110,7 @@ class MigrationPlanRunSerializer(serializers.Serializer):
     """
     validate = serializers.BooleanField(
         help_text=_('If ``True``, migration cannot happen without successful validation '
-                    'of the Migration Plan'),
+                    'of the Migration Plan.'),
         required=False,
         default=False,
         write_only=True
@@ -122,6 +122,15 @@ class MigrationPlanRunSerializer(serializers.Serializer):
         default=False,
         write_only=True
     )
+    skip_corrupted = serializers.BooleanField(
+        help_text=_('If ``True``, skips corrupted or missing Pulp 2 content without causing a task '
+                    'failure. If you need this content, run a sync task in Pulp 3 for a repo of '
+                    'interest to bring any missing content back. Alternatively, repair it in Pulp 2'
+                    'and re-run the migration task.'),
+        required=False,
+        default=False,
+        write_only=True
+    )
 
 
 class Pulp2ContentSerializer(ModelSerializer):
@@ -227,30 +236,8 @@ class Pulp2RepositoriesSerializer(ModelSerializer):
         """
         Get pulp3_distribution_hrefs from pulp3_repository_version
         """
-        dist_list = []
-        rv = obj.pulp3_repository_version
-        if not rv:
-            return dist_list
-        result_qs = rv.publication_set.all()
-        if result_qs:
-            # repo_version  has publication, therefore is a PublicationDistribution
-            for publication in result_qs:
-                distribution_type = f'{publication.pulp_type.replace(".", "_")}distribution'
-                plugin_distribution = getattr(publication, distribution_type)
-                dist_list.extend(plugin_distribution.all())
-        else:
-            # empty result_qs means that repo_version does not need publication,
-            # or repo_version was not published/distributed
-            pulp_type = rv.repository.pulp_type
-            distribution_type = f'{pulp_type.replace(".", "_")}distribution'
-            if hasattr(rv, distribution_type):
-                # repo_version is distributed directly trough RepositoryDistribution
-                plugin_distribution = getattr(rv, distribution_type)
-                dist_list = plugin_distribution.all()
-            else:
-                # repo_version was not published/distributed
-                return dist_list
-        return [get_pulp_href(dist) for dist in dist_list]
+        pulp2dists = obj.pulp2_dists.filter(not_in_plan=False, is_migrated=True)
+        return [get_pulp_href(dist.pulp3_distribution) for dist in pulp2dists]
 
     class Meta:
         fields = ModelSerializer.Meta.fields + (
