@@ -16,9 +16,15 @@ from pulpcore.client.pulp_2to3_migration import (
     ApiClient as MigrationApiClient,
     MigrationPlansApi
 )
+from pulp_2to3_migration.tests.functional.util import (
+    get_psql_smash_cmd,
+    monitor_task
+)
 
-from pulp_2to3_migration.tests.functional.util import monitor_task
+from pulp_smash import cli
+from pulp_smash import config as smash_config
 
+from .constants import TRUNCATE_TABLES_QUERY_BASH
 
 PULP_2_ISO_FIXTURE_DATA = {
     'file': 3,
@@ -86,13 +92,15 @@ DIFFERENT_IMPORTER_MIGRATION_PLAN = json.dumps({
 
 
 # TODO:
-#   - Clear DB after each test
 #   - Check that distributions are created properly
 #   - Check that remotes are created properly
 
 class TestMigrationPlan(unittest.TestCase):
     """Test the APIs for creating a Migration Plan."""
 
+    smash_cfg = smash_config.get_config()
+    smash_cli_client = cli.Client(smash_cfg)
+
     @classmethod
     def setUpClass(cls):
         """
@@ -115,9 +123,16 @@ class TestMigrationPlan(unittest.TestCase):
         cls.tasks_api = TasksApi(core_client)
         cls.migration_plans_api = MigrationPlansApi(migration_client)
 
+    def tearDown(self):
+        """
+        Clean up the database after each test
+        """
+        cmd = get_psql_smash_cmd(TRUNCATE_TABLES_QUERY_BASH)
+        self.smash_cli_client.run(cmd, sudo=True)
+
     def _do_test(self, repos, migration_plan):
         mp = self.migration_plans_api.create({'plan': migration_plan})
-        mp_run_response = self.migration_plans_api.run(mp.pulp_href, data={})
+        mp_run_response = self.migration_plans_api.run(mp.pulp_href, {})
         task = monitor_task(self.tasks_api, mp_run_response.task)
         self.assertEqual(task.state, "completed")
         for repo_id in repos:
@@ -149,5 +164,5 @@ class TestMigrationPlan(unittest.TestCase):
 
     def test_3_migrate_iso_repositories_with_different_importer(self):
         """Test that a Migration Plan with different importers executes correctly."""
-        repos = list(PULP_2_ISO_FIXTURE_DATA.keys())
+        repos = list(PULP_2_ISO_FIXTURE_DATA.keys())[:2]
         self._do_test(repos, DIFFERENT_IMPORTER_MIGRATION_PLAN)
